import { ViewArray } from '../services/view-array/view-array';


/**
 * A type representing local application data.
 */
export type Local = {
  contexts?: string[];
  dockerContext?: string;
  dockerfileLocations?: any;
  dockerfilePath?: string;
  hasValidContextLocation?: boolean;
  hasValidDockerfilePath?: boolean;
  maxScore?: number;
  namespaceOptions?: {
    filter: string;
    predicate: string;
    reverse: boolean;
    page: number;
  };
  namespaces?: Namespace[];
  orderedNamespaces?: ViewArray;
  orderedRepositories?: ViewArray;
  orderedRobotAccounts?: ViewArray;
  repositories?: Repository[];
  repositoryFullRefs?: {
    icon: string;
    title: string;
    value: string;
  }[];
  repositoryOptions?: {
    filter: string;
    predicate: string;
    reverse: boolean;
    page: number;
    hideStale: boolean;
  };
  repositoryRefs?: {
    kind: string;
    name: string;
  }[];
  robotAccount?: RobotAccount;
  robotOptions?: {
    filter: string;
    predicate: string;
    reverse: boolean;
    page: number;
  };
  selectedNamespace?: Namespace;
  selectedRepository?: Repository;
  triggerAnalysis?: any;
  triggerOptions?: {
    [key: string]: boolean;
  };
};


/**
 * A type representing a robot account.
 */
export type RobotAccount = {
  can_read: boolean;
  is_robot: boolean;
  kind: string;
  name: string;
};


/**
 * A type representing a Git repository.
 */
export type Repository = {
  description: string;
  full_name: string;
  has_admin_permissions: boolean;
  last_updated: number;
  last_updated_datetime: Date;
  name: string;
  private: boolean;
  url: string;
  namespace?: string;
  trust_enabled: boolean;
}


/**
 * A type representing a repository namespace.
 */
export type Namespace = {
  avatar_url: string;
  id: string;
  personal: boolean;
  score: number;
  title: string;
  url: string;
};


/**
 * A type representing a trigger.
 */
export type Trigger = {
  id: number;
  service: any;
};


/**
 * Represents an apostille signature document, with extra expiration information.
 */
export type ApostilleSignatureDocument = {
  // When the signed document expires.
  expiration: string

  // Object of information for each tag.
  tags: {string: ApostilleTagDocument}

  // If true, an error occurred while trying to load this document.
  error: boolean
};


/**
 * An apostille document containing signatures for a tag.
 */
export type ApostilleTagDocument = {
  // The length of the document.
  length: number

  // The hashes for the tag.
  hashes: {string: string}
};


/**
 * A type representing a Markdown symbol.
 */
export type MarkdownSymbol = 'heading1'
                           | 'heading2'
                           | 'heading3'
                           | 'bold'
                           | 'italics'
                           | 'bulleted-list'
                           | 'numbered-list'
                           | 'quote'
                           | 'code'
                           | 'link'
                           | 'code';
